Struct core::num::ParseIntErrorStable
[-] [+]
[src]
pub struct ParseIntError {
// some fields omitted
}An error which can be returned when parsing an integer.
pub struct ParseIntError {
// some fields omitted
}An error which can be returned when parsing an integer.
impl ParseIntErrorfn description(&self) -> &strimpl Display for ParseIntErrorimpl PartialEq for ParseIntErrorfn eq(&self, __arg_0: &ParseIntError) -> boolfn ne(&self, __arg_0: &ParseIntError) -> boolimpl Clone for ParseIntErrorfn clone(&self) -> ParseIntErrorfn clone_from(&mut self, source: &Self)impl Debug for ParseIntError
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).